Enum network::protocols::wire::handshake::v1::MessagingProtocolVersion [−][src]
pub enum MessagingProtocolVersion {
V1,
}Expand description
Enum representing different versions of the Diem network protocol. These
should be listed from old to new, old having the smallest value. We derive
PartialOrd since nodes need to find highest intersecting protocol version.
Variants